@@ -93,7 +93,7 @@ const Application = new Lang.Class({
         let path = GLib.build_filenamev([GLib.get_home_dir(), _("Recordings")]);
 
         // Ensure Recordings directory
-        GLib.mkdir_with_parents(path, 0755);
+        GLib.mkdir_with_parents(path, parseInt("0755", 8));
         this.saveDir = Gio.file_new_for_path(path);
     },
 
@@ -128,6 +128,15 @@ const Application = new Lang.Class({
     setPreferences: function(profileName) {
         settings.set_int("media-type-preset", profileName);
     },
+
+    getChannelsPreferences: function() {
+        let set = settings.get_int("channel");
+        return set;
+    },
+
+    setChannelsPreferences: function(channel) {
+        settings.set_int("channel", channel);
+    },
      
     getMicVolume: function() {
         let micVolLevel = settings.get_double("mic-volume");
@@ -159,7 +168,7 @@ const Application = new Lang.Class({
         aboutDialog.program_name = _("Sound Recorder");
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
-        aboutDialog.logo_icon_name = 'audio-input-microphone';
+        aboutDialog.logo_icon_name = 'gnome-sound-recorder';
         aboutDialog.version = pkg.version;
         aboutDialog.website = 'http://live.gnome.org/GnomeSoundRecorder';
         aboutDialog.wrap_license = true;
